@@ -150,10 +150,6 @@ def find_resource(manager, name_or_id):
         raise exc.CommandError(msg)
 
 
-def string_to_bool(arg):
-    return arg.strip().lower() in ('t', 'true', 'yes', '1')
-
-
 def env(*vars, **kwargs):
     """Search for the first defined of possibly many env vars
 
