@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright 2013 Red Hat, Inc.
 # All Rights Reserved.
@@ -20,7 +19,8 @@ from ironicclient.common import utils
 
 
 def _print_port_show(port):
-    fields = ['uuid', 'address', 'created_at', 'updated_at', 'extra']
+    fields = ['address', 'created_at', 'extra', 'node_uuid', 'updated_at',
+              'uuid']
     data = dict([(f, getattr(port, f, '')) for f in fields])
     utils.print_dict(data, wrap=72)
 
